@@ -21,11 +21,11 @@ fn test_linux_device_cgroup_to_string() {
 
     let ldc = LinuxDeviceCgroupBuilder::default()
         .allow(true)
-        .typ(LinuxDeviceType::B)
+        .typ(LinuxDeviceType::A)
         .major(1)
         .minor(9)
         .access("rwm".to_string())
         .build()
         .expect("build device cgroup");
-    assert_eq!(ldc.to_string(), "b 1:9 rwm");
+    assert_eq!(ldc.to_string(), "a 1:9 rwm");
 }
